diff --git a/fedora-cloud.conf b/fedora-cloud.conf
index 4375005..da42b7c 100644
--- a/fedora-cloud.conf
+++ b/fedora-cloud.conf
@@ -186,6 +186,7 @@ volume_id_substitutions = {
'Rawhide': 'rawh',
'Astronomy_KDE': 'AstK',
'Silverblue': 'SB',
+ 'Kinoite': 'Knt',
'Cinnamon': 'Cinn',
'Cloud': 'C',
'Design_suite': 'Dsgn',
diff --git a/fedora-container.conf b/fedora-container.conf
index 13fff88..fb980ae 100644
--- a/fedora-container.conf
+++ b/fedora-container.conf
@@ -186,6 +186,7 @@ volume_id_substitutions = {
'Rawhide': 'rawh',
'Astronomy_KDE': 'AstK',
'Silverblue': 'SB',
+ 'Kinoite': 'Knt',
'Cinnamon': 'Cinn',
'Cloud': 'C',
'Design_suite': 'Dsgn',
diff --git a/fedora.conf b/fedora.conf
index 7715280..d010c73 100644
--- a/fedora.conf
+++ b/fedora.conf
@@ -272,6 +272,7 @@ volume_id_substitutions = {
'Rawhide': 'rawh',
'Astronomy_KDE': 'AstK',
'Silverblue': 'SB',
+ 'Kinoite': 'Knt',
'Cinnamon': 'Cinn',
'Cloud': 'C',
'Comp_Neuro': 'CNr',
@@ -739,6 +740,19 @@ ostree = {
"ostree_ref": "fedora/rawhide/${basearch}/silverblue",
"arches": ["x86_64", "ppc64le", "aarch64"],
"failable": ['*'],
+ },
+ "^Kinoite$": {
+ "version": "!OSTREE_VERSION_FROM_LABEL_DATE_TYPE_RESPIN",
+ "force_new_commit": True,
+ "treefile": "fedora-kinoite.yaml",
+ "config_url": "https://pagure.io/workstation-ostree-config.git",
+ "config_branch": "main",
+ "repo": "Everything",
+ "tag_ref": False,
+ "ostree_repo": "/mnt/koji/compose/ostree/repo/",
+ "ostree_ref": "fedora/rawhide/${basearch}/kinoite",
+ "arches": ["x86_64", "ppc64le", "aarch64"],
+ "failable": ['*'],
}
}
@@ -823,6 +837,87 @@ ostree_installer = [
'extra_runroot_pkgs': ['flatpak', 'dbus-daemon'],
'failable': ['*'],
}
+ }),
+ ("^Kinoite$", {
+ "x86_64": {
+ "repo": "Everything",
+ "release": None,
+ "rootfs_size": "8",
+ "add_template": ["ostree-based-installer/lorax-configure-repo.tmpl",
+ "ostree-based-installer/lorax-embed-repo.tmpl",
+ "ostree-based-installer/lorax-embed-flatpaks.tmpl"],
+ "add_template_var": [
+ "ostree_install_repo=https://kojipkgs.fedoraproject.org/compose/ostree/repo/",
+ "ostree_update_repo=https://ostree.fedoraproject.org",
+ "ostree_osname=fedora",
+ "ostree_oskey=fedora-35-primary",
+ "ostree_contenturl=mirrorlist=https://ostree.fedoraproject.org/mirrorlist",
+ "ostree_install_ref=fedora/rawhide/x86_64/kinoite",
+ "ostree_update_ref=fedora/rawhide/x86_64/kinoite",
+ "flatpak_remote_name=fedora",
+ # using registry-no-cdn avoids redirects to the CDN;
+ # needed because of network restrictions on koji runroot
+ "flatpak_remote_url=oci+https://registry-no-cdn.fedoraproject.org",
+ "flatpak_remote_refs=runtime/org.fedoraproject.Platform/x86_64/f34",
+ ],
+ 'template_repo': 'https://pagure.io/fedora-lorax-templates.git',
+ 'template_branch': 'main',
+ # dbus-run-session is needed for Flatpak to talk to flatpak-oci-authenticator
+ 'extra_runroot_pkgs': ['flatpak', 'dbus-daemon'],
+ 'failable': ['*'],
+ },
+ "ppc64le": {
+ "repo": "Everything",
+ "release": None,
+ "rootfs_size": "8",
+ "add_template": ["ostree-based-installer/lorax-configure-repo.tmpl",
+ "ostree-based-installer/lorax-embed-repo.tmpl"],
+ "add_template_var": [
+ "ostree_install_repo=https://kojipkgs.fedoraproject.org/compose/ostree/repo/",
+ "ostree_update_repo=https://ostree.fedoraproject.org",
+ "ostree_osname=fedora",
+ "ostree_oskey=fedora-35-primary",
+ "ostree_contenturl=mirrorlist=https://ostree.fedoraproject.org/mirrorlist",
+ "ostree_install_ref=fedora/rawhide/ppc64le/kinoite",
+ "ostree_update_ref=fedora/rawhide/ppc64le/kinoite",
+ "flatpak_remote_name=fedora",
+ # using registry-no-cdn avoids redirects to the CDN;
+ # needed because of network restrictions on koji runroot
+ "flatpak_remote_url=oci+https://registry-no-cdn.fedoraproject.org",
+ "flatpak_remote_refs=",
+ ],
+ 'template_repo': 'https://pagure.io/fedora-lorax-templates.git',
+ 'template_branch': 'main',
+ # dbus-run-session is needed for Flatpak to talk to flatpak-oci-authenticator
+ 'extra_runroot_pkgs': ['flatpak', 'dbus-daemon'],
+ 'failable': ['*'],
+ },
+ "aarch64": {
+ "repo": "Everything",
+ "release": None,
+ "rootfs_size": "8",
+ "add_template": ["ostree-based-installer/lorax-configure-repo.tmpl",
+ "ostree-based-installer/lorax-embed-repo.tmpl"],
+ "add_template_var": [
+ "ostree_install_repo=https://kojipkgs.fedoraproject.org/compose/ostree/repo/",
+ "ostree_update_repo=https://ostree.fedoraproject.org",
+ "ostree_osname=fedora",
+ "ostree_oskey=fedora-35-primary",
+ "ostree_contenturl=mirrorlist=https://ostree.fedoraproject.org/mirrorlist",
+ "ostree_install_ref=fedora/rawhide/aarch64/kinoite",
+ "ostree_update_ref=fedora/rawhide/aarch64/kinoite",
+ "flatpak_remote_name=fedora",
+ # using registry-no-cdn avoids redirects to the CDN;
+ # needed because of network restrictions on koji runroot
+ "flatpak_remote_url=oci+https://registry-no-cdn.fedoraproject.org",
+ "flatpak_remote_refs=",
+ ],
+ 'template_repo': 'https://pagure.io/fedora-lorax-templates.git',
+ 'template_branch': 'main',
+ # dbus-run-session is needed for Flatpak to talk to flatpak-oci-authenticator
+ 'extra_runroot_pkgs': ['flatpak', 'dbus-daemon'],
+ 'failable': ['*'],
+ }
})
]
diff --git a/variants-fedora.xml b/variants-fedora.xml
index 8ebc998..cdfbfcb 100644
--- a/variants-fedora.xml
+++ b/variants-fedora.xml
@@ -86,6 +86,13 @@
ppc64le
+
+
+ aarch64
+ x86_64
+ ppc64le
+
+
armhfp
diff --git a/nightly.sh b/nightly.sh
index fecbe15..22952ee 100755
--- a/nightly.sh
+++ b/nightly.sh
@@ -124,13 +124,27 @@ fi
# armhfp/aarch64/x86_64 for Everything Cloud Container Modular Server Workstation is primary
$RSYNCPREFIX compose-partial-copy --arch=armhfp --arch=aarch64 --arch=x86_64 --arch src \
"$DESTDIR" "$RSYNCTARGET/" \
- --variant Everything --variant Cloud --variant Container --variant Modular \
- --variant Server --variant Spins --variant Silverblue --variant Workstation \
+ --variant Everything \
+ --variant Cloud \
+ --variant Container \
+ --variant Modular \
+ --variant Server \
+ --variant Spins \
+ --variant Silverblue \
+ --variant Kinoite \
+ --variant Workstation \
--link-dest="$RSYNCTARGET/Everything" --exclude=repodata
$RSYNCPREFIX compose-partial-copy --arch=armhfp --arch=aarch64 --arch=x86_64 --arch src \
"$DESTDIR" "$RSYNCTARGET/" \
- --variant Everything --variant Cloud --variant Container --variant Modular \
- --variant Server --variant Spins --variant Silverblue --variant Workstation \
+ --variant Everything \
+ --variant Cloud \
+ --variant Container \
+ --variant Modular \
+ --variant Server \
+ --variant Spins \
+ --variant Silverblue \
+ --variant Kinoite \
+ --variant Workstation \
--link-dest="$RSYNCTARGET/Everything" --delete-after
$RSYNCPREFIX rm "$RSYNCTARGET/.composeinfo"
@@ -180,17 +194,19 @@ $RSYNCPREFIX ./releng/scripts/build_composeinfo "$RSYNCSECTARGET/" --name "$NEWC
# hardlink content (this will hardlink ppc64le/s390x)
time hardlink -v "$RSYNCSECTARGET/.."
# sync Silverblue to the unified ostree repo
# Set the umask to so directories can get group write
# https://pagure.io/releng/issue/8811
old_umask=$(umask)
umask 0002
-for arch in x86_64 ppc64le aarch64; do
- ref="fedora/rawhide/${arch}/silverblue"
- if ! ostree --repo=$OSTREESRCREPO rev-parse "${ref}"; then continue; fi
+for variant in 'silverblue' 'kinoite'; do
+ for arch in x86_64 ppc64le aarch64; do
+ ref="fedora/rawhide/${arch}/${variant}"
+ if ! ostree --repo=$OSTREESRCREPO rev-parse "${ref}"; then continue; fi
- ostree pull-local --repo=$OSTREEDESTREPO $OSTREESRCREPO --depth=-1 "${ref}"
- ostree summary -u --repo=$OSTREEDESTREPO # update summary file
+ ostree pull-local --repo=$OSTREEDESTREPO $OSTREESRCREPO --depth=-1 "${ref}"
+ ostree summary -u --repo=$OSTREEDESTREPO # update summary file
+ done
done
# Set to old umask
umask $old_umask
@@ -180,17 +194,19 @@ $RSYNCPREFIX ./releng/scripts/build_composeinfo "$RSYNCSECTARGET/" --name "$NEWC
# hardlink content (this will hardlink ppc64le/s390x)
time hardlink -v "$RSYNCSECTARGET/.."
-# sync Silverblue to the unified ostree repo
+# sync Silverblue and Kinoite to the unified ostree repo
# Set the umask to so directories can get group write
# https://pagure.io/releng/issue/8811